=====================================
Validation Infrastructure for Tendril
=====================================

.. image:: https://img.shields.io/travis/chintal/tendril-validation.svg
        :target: https://travis-ci.org/chintal/tendril-validation

.. image:: https://img.shields.io/pypi/v/tendril-validation.svg
        :target: https://pypi.python.org/pypi/tendril-validation

* License: AGPLv3
* Documentation: http://tendril-validation.readthedocs.org


Validation Infrastructure for Tendril
